aboutsummaryrefslogtreecommitdiffstats
path: root/window.c
diff options
context:
space:
mode:
authorBerke Kocaoğlu <berke.kocaoglu@metu.edu.tr>2021-09-16 11:32:59 +0200
committerBerke Kocaoğlu <berke.kocaoglu@metu.edu.tr>2021-09-16 21:55:31 +0200
commit7cce7ea857321c854fc9e061edee3a32f4831d18 (patch)
treed8ad4f168d67a433278912a8d07231760aff5cbc /window.c
parent9c73646d9c709005301d5be93d0232d89201b21e (diff)
downloadnsxiv-7cce7ea857321c854fc9e061edee3a32f4831d18.tar.zst
Rename, Update Docs and Prepare for Release (#9)
Co-authored-by: Guilherme Rugai Freire <41879254+GRFreire@users.noreply.github.com> Co-authored-by: N-R-K <79544946+N-R-K@users.noreply.github.com> Co-authored-by: NRK <nrk@disroot.org> Co-authored-by: Arthur Williams <taaparthur@gmail.com> Co-authored-by: eylles <ed.ylles1997@gmail.com>
Diffstat (limited to 'window.c')
-rw-r--r--window.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/window.c b/window.c
index dd17134..3cd6c4a 100644
--- a/window.c
+++ b/window.c
@@ -1,22 +1,22 @@
/* Copyright 2011-2013 Bert Muennich
*
* This file is part of sxiv.
*
* sxiv is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published
* by the Free Software Foundation; either version 2 of the License,
* or (at your option) any later version.
*
* sxiv is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with sxiv. If not, see <http://www.gnu.org/licenses/>.
+ * along with nsxiv. If not, see <http://www.gnu.org/licenses/>.
*/
-#include "sxiv.h"
+#include "nsxiv.h"
#define _WINDOW_CONFIG
#include "config.h"
#include "icon/data.h"
@@ -30,7 +30,7 @@
#include <X11/Xatom.h>
#include <X11/Xresource.h>
-#define RES_CLASS "Sxiv"
+#define RES_CLASS "Nsxiv"
enum {
H_TEXT_PAD = 5,
@@ -277,11 +277,11 @@ void win_open(win_t *win)
free(icon_data);
/* These two atoms won't change and thus only need to be set once. */
- XStoreName(win->env.dpy, win->xwin, "sxiv");
- XSetIconName(win->env.dpy, win->xwin, "sxiv");
+ XStoreName(win->env.dpy, win->xwin, "nsxiv");
+ XSetIconName(win->env.dpy, win->xwin, "nsxiv");
classhint.res_class = RES_CLASS;
- classhint.res_name = options->res_name != NULL ? options->res_name : "sxiv";
+ classhint.res_name = options->res_name != NULL ? options->res_name : "nsxiv";
XSetClassHint(e->dpy, win->xwin, &classhint);
XSetWMProtocols(e->dpy, win->xwin, &atoms[ATOM_WM_DELETE_WINDOW], 1);
@@ -1,22 +1,22 @@
/* Copyright 2011-2013 Bert Muennich
*
- * This file is part of sxiv.
+ * This file is a part of nsxiv.
*
@@ -1,22 +1,22 @@
*
- * sxiv is free software; you can redistribute it and/or modify
+ * nsxiv is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published
* by the Free Software Foundation; either version 2 of the License,
@@ -1,22 +1,22 @@
* or (at your option) any later version.
*
- * sxiv is distributed in the hope that it will be useful,
+ * nsxiv is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the